@@ -115,8 +115,8 @@ class TlmsWmsEntDirect(models.Model):
     transit_time = models.DateField(verbose_name="核放时间", help_text="核放时间", null=True, blank=True)
     # tlms
     contract_no = models.CharField(max_length=30, verbose_name="合同号/订单号", help_text="合同号/订单号")
-    dec_method = models.CharField(max_length=30, verbose_name="申报方式", help_text="申报方式")
-    work_route = models.CharField(max_length=30, verbose_name="作业路线", help_text="作业路线")
+    dec_method = models.CharField(max_length=30, verbose_name="申报方式", help_text="申报方式", null=True, blank=True)
+    work_route = models.CharField(max_length=30, verbose_name="作业路线", help_text="作业路线", null=True, blank=True)
     js_no = models.CharField(max_length=30, verbose_name="js备案号", help_text="js备案号", null=True, blank=True)
     source_port = models.CharField(max_length=50, verbose_name="起运港", help_text="起运港", null=True, blank=True)
     vessel = models.CharField(max_length=30, verbose_name="船名", help_text="船名", null=True, blank=True)
@@ -128,6 +128,8 @@ class TlmsWmsEntDirect(models.Model):
     transaction_mode = models.CharField(max_length=50, verbose_name="成交方式", help_text="成交方式", null=True, blank=True)
     est_arrival_time = models.DateField(verbose_name="预计到港日期", help_text="预计到港日期", null=True, blank=True)
     arrival_time = models.DateField(verbose_name="到港日期", help_text="到港日期", null=True, blank=True)
+    sender = models.CharField(max_length=100, verbose_name="发货人", null=True, blank=True)
+    receiver = models.CharField(max_length=100, verbose_name="收货人", null=True, blank=True)
     # wms
     remark = models.CharField(max_length=200, verbose_name="备注", help_text="备注", null=True, blank=True)
     plan_ent_date = models.DateTimeField(verbose_name="出入库时间")
